@@ -60,7 +60,16 @@ def print_phononpy():
  |_|                            |_|    |___/""")
 
 def print_version(version):
-    print(('%s' % version).rjust(44))
+    try:
+        import pkg_resources
+        ver = pkg_resources.require("phonopy")[0].version.split('.')
+        if len(ver) > 3:
+            rev = ver[3]
+            print(('%s-r%s' % (version, rev)).rjust(44))
+        else:
+            print(('%s' % version).rjust(44))
+    except ImportError:
+        print(('%s' % version).rjust(44))
     print('')
 
 def print_end():
@@ -700,8 +709,13 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
             comment = None
         else:
             comment = {'calculator': interface_mode}
-        phonon.write_yaml_band_structure(labels=settings.get_band_labels(),
-                                         comment=comment)
+
+        if settings.get_is_hdf5():
+            phonon.write_hdf5_band_structure(labels=settings.get_band_labels(),
+                                             comment=comment)
+        else:
+            phonon.write_yaml_band_structure(labels=settings.get_band_labels(),
+                                             comment=comment)
 
         if options.is_graph_plot and run_mode != 'band_mesh':
             plot = phonon.plot_band_structure(labels=settings.get_band_labels())
